@@ -22,16 +22,16 @@
  * means only the basic inode info is checked, no fork checks.
  */
 static int
-check_aginode_block(xfs_mount_t	*mp,
-			xfs_agnumber_t	agno,
-			xfs_agblock_t	agbno)
+check_aginode_block(
+	xfs_mount_t		*mp,
+	xfs_agnumber_t		agno,
+	xfs_agblock_t		agbno)
 {
-
-	xfs_dinode_t	*dino_p;
-	int		i;
-	int		cnt = 0;
-	struct xfs_buf	*bp;
-	int		error;
+	struct xfs_dinode	*dino_p;
+	int			i;
+	int			cnt = 0;
+	struct xfs_buf		*bp;
+	int			error;
 
 	/*
 	 * it's ok to read these possible inode blocks in one at
@@ -598,7 +598,7 @@ process_inode_chunk(
 	xfs_ino_t		parent;
 	ino_tree_node_t		*ino_rec;
 	struct xfs_buf		**bplist;
-	xfs_dinode_t		*dino;
+	struct xfs_dinode	*dino;
 	int			icnt;
 	int			status;
 	int			bp_found;
@@ -628,7 +628,7 @@ process_inode_chunk(
 	if (cluster_count == 0)
 		cluster_count = 1;
 
-	if (xfs_sb_version_hassparseinodes(&mp->m_sb) &&
+	if (xfs_has_sparseinodes(mp) &&
 	    M_IGEO(mp)->inodes_per_cluster >= XFS_INODES_PER_HOLEMASK_BIT)
 		can_punch_sparse = true;
 
@@ -686,7 +686,7 @@ process_inode_chunk(
 		}
 
 		pftrace("readbuf %p (%llu, %d) in AG %d", bplist[bp_index],
-			(long long)XFS_BUF_ADDR(bplist[bp_index]),
+			(long long)xfs_buf_daddr(bplist[bp_index]),
 			bplist[bp_index]->b_length, agno);
 
 		bplist[bp_index]->b_ops = &xfs_inode_buf_ops;
@@ -985,7 +985,7 @@ process_next:
 
 				pftrace("put/writebuf %p (%llu) in AG %d",
 					bplist[bp_index], (long long)
-					XFS_BUF_ADDR(bplist[bp_index]), agno);
+					xfs_buf_daddr(bplist[bp_index]), agno);
 
 				if (dirty && !no_modify) {
 					libxfs_buf_mark_dirty(bplist[bp_index]);
